@@ -1,5 +1,5 @@
 /* Hiearchic listboxes browser dialog commons */
-/* $Id: hierbox.c,v 1.201.2.6 2005/04/06 09:11:18 jonas Exp $ */
+/* $Id: hierbox.c,v 1.201.2.7 2005/05/01 21:05:57 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -259,8 +259,7 @@ hierbox_ev_abort(struct dialog_data *dlg_data)
 	struct hierbox_dialog_list_item *item;
 
 	/* Save state and delete the box structure */
-	/* FIXME: It's workaround for bug 397. Real fix is needed. */
-	if (browser != &download_browser)
+	if (!browser->do_not_save_state)
 		copy_struct(&browser->box_data, box);
 	del_from_list(box);
 
