@@ -1,5 +1,5 @@
 /* Input field widget implementation. */
-/* $Id: inpfield.c,v 1.190.2.6 2005/04/06 09:10:41 jonas Exp $ */
+/* $Id: inpfield.c,v 1.190.2.8 2005/09/14 12:04:23 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -55,11 +55,11 @@ t_handler_event_status
 check_number(struct dialog_data *dlg_data, struct widget_data *widget_data)
 {
 	struct widget *widget = widget_data->widget;
-	unsigned char *end;
+	char *end;
 	long l;
 
 	errno = 0;
-	l = strtol(widget_data->cdata, (char **) &end, 10);
+	l = strtol(widget_data->cdata, &end, 10);
 
 	if (errno || !*widget_data->cdata || *end) {
 		info_box(dlg_data->win->term, 0,
@@ -335,32 +335,39 @@ mouse_field(struct dialog_data *dlg_data, struct widget_data *widget_data)
 {
 	struct term_event *ev = dlg_data->term_event;
 
-	if (!widget_has_history(widget_data))
-		return EVENT_NOT_PROCESSED;
-
 	if (!check_mouse_position(ev, &widget_data->box))
 		return EVENT_NOT_PROCESSED;
 
+	/* Handle navigation through history (if any) using up/down mouse wheel */
 	switch (get_mouse_button(ev)) {
 		case B_WHEEL_UP:
+			if (!widget_has_history(widget_data))
+				return EVENT_NOT_PROCESSED;
+
 			if (check_mouse_action(ev, B_DOWN) &&
 			    (void *) widget_data->info.field.cur_hist->prev != &widget_data->info.field.history) {
 				widget_data->info.field.cur_hist = widget_data->info.field.cur_hist->prev;
 				dlg_set_history(widget_data);
 				select_widget(dlg_data, widget_data);
+				return EVENT_PROCESSED;
 			}
-			return EVENT_PROCESSED;
+			return EVENT_NOT_PROCESSED;
 
 		case B_WHEEL_DOWN:
+			if (!widget_has_history(widget_data))
+				return EVENT_NOT_PROCESSED;
+
 			if (check_mouse_action(ev, B_DOWN) &&
 			    (void *) widget_data->info.field.cur_hist != &widget_data->info.field.history) {
 				widget_data->info.field.cur_hist = widget_data->info.field.cur_hist->next;
 				dlg_set_history(widget_data);
 				select_widget(dlg_data, widget_data);
+				return EVENT_PROCESSED;
 			}
-			return EVENT_PROCESSED;
+			return EVENT_NOT_PROCESSED;
 	}
 
+	/* Place text cursor at mouse position and focus the widget. */
 	widget_data->info.field.cpos = widget_data->info.field.vpos
 				     + ev->info.mouse.x - widget_data->box.x;
 	int_upper_bound(&widget_data->info.field.cpos, strlen(widget_data->cdata));
