@@ -1,5 +1,5 @@
 /* Menu system implementation. */
-/* $Id: menu.c,v 1.286.4.2 2005/04/05 21:08:40 jonas Exp $ */
+/* $Id: menu.c,v 1.286.4.3 2005/09/14 13:24:34 jonas Exp $ */
 
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE /* XXX: we _WANT_ strcasestr() ! */
@@ -444,6 +444,12 @@ display_menu(struct terminal *term, struct menu *menu)
 	draw_box(term, &box, ' ', 0, normal_color);
 	draw_border(term, &box, frame_color, 1);
 
+	if (get_opt_bool("ui.dialogs.shadows")) {
+		/* Draw shadow */
+		draw_shadow(term, &menu->box,
+			    get_bfu_color(term, "dialog.shadow"), 2, 1);
+	}
+
 	menu_height = box.height;
 	box.height = 1;
 
