@@ -1,5 +1,5 @@
 /* Cache subsystem */
-/* $Id: cache.c,v 1.194.2.2 2005/04/05 21:08:40 jonas Exp $ */
+/* $Id: cache.c,v 1.194.2.4 2005/05/02 21:14:03 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -161,6 +161,12 @@ get_cache_entry(struct uri *uri)
 	return cached;
 }
 
+static int
+cache_entry_has_expired(struct cache_entry *cached)
+{
+	return cached->max_age <= time(NULL);
+}
+
 struct cache_entry *
 get_validated_cache_entry(struct uri *uri, enum cache_mode cache_mode)
 {
@@ -176,14 +182,27 @@ get_validated_cache_entry(struct uri *uri, enum cache_mode cache_mode)
 		return NULL;
 
 	/* Check if the entry can be deleted */
-	if (is_object_used(cached))
+	/* FIXME: This does not make sense to me. Why should the usage pattern
+	 * of the cache entry matter? Only reason I can think of is to avoid
+	 * reloading when spawning a new tab which could potentially be a big
+	 * penalty but shouldn't that be taken care of on a higher level?
+	 * --jonas */
+	if (is_object_used(cached)) {
+#if 0
+		/* Never use expired entries. */
+		if (cached->expire && cache_entry_has_expired(cached))
+			return NULL;
+#endif
 		return cached;
+	}
 
 	/* A bit of a gray zone. Delete the entry if the it has the stricktest
 	 * cache mode and we don't want the most aggressive mode or we have to
-	 * remove the redirect. Please enlighten me. --jonas */
+	 * remove the redirect or the entry expired. Please enlighten me.
+	 * --jonas */
 	if ((cached->cache_mode == CACHE_MODE_NEVER && cache_mode != CACHE_MODE_ALWAYS)
-	    || (cached->redirect && !get_opt_bool("document.cache.cache_redirects"))) {
+	    || (cached->redirect && !get_opt_bool("document.cache.cache_redirects"))
+	    || (cached->expire && cache_entry_has_expired(cached))) {
 		delete_cache_entry(cached);
 		return NULL;
 	}
@@ -774,6 +793,10 @@ garbage_collection(int whole)
 			continue;
 		}
 
+		/* FIXME: Optionally take cached->max_age into consideration,
+		 * but that will probably complicate things too much. We'd have
+		 * to sort entries so prioritize removing the oldest entries. */
+
 		/* Mark me for destruction, sir. */
 		cached->gc_target = 1;
 		new_cache_size -= cached->data_size;
