@@ -1,5 +1,5 @@
 /* Cache-related dialogs */
-/* $Id: dialogs.c,v 1.79.4.1 2005/04/06 09:11:18 jonas Exp $ */
+/* $Id: dialogs.c,v 1.79.4.2 2005/05/01 22:47:54 jonas Exp $ */
 
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE /* XXX: we _WANT_ strcasestr() ! */
@@ -22,6 +22,7 @@
 #include "sched/session.h"
 #include "terminal/draw.h"
 #include "terminal/terminal.h"
+#include "util/conv.h"
 #include "util/memory.h"
 #include "util/object.h"
 #include "util/string.h"
@@ -117,6 +118,13 @@ get_cache_entry_info(struct listbox_item *item, struct terminal *term)
 		if (!cached->valid) add_to_string(&msg, _("invalid", term));
 	}
 
+#ifdef HAVE_STRFTIME
+	if (cached->expire) {
+		add_format_to_string(&msg, "\n%s: ", _("Expires", term));
+		add_date_to_string(&msg, get_opt_str("ui.date_format"), &cached->max_age);
+
+	}
+#endif
 #ifdef CONFIG_DEBUG
 	add_format_to_string(&msg, "\n%s: %d", "Refcount", get_object_refcount(cached));
 	add_format_to_string(&msg, "\n%s: %d", _("ID", term), cached->id);
