@@ -1,5 +1,5 @@
 /* Command line processing */
-/* $Id: cmdline.c,v 1.107.2.3 2005/04/06 11:07:48 jonas Exp $ */
+/* $Id: cmdline.c,v 1.107.2.8 2005/09/13 22:25:11 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -44,7 +44,7 @@
 /* Hack to handle URL extraction for -remote commands */
 static unsigned char *remote_url;
 
-static int
+static enum retval
 parse_options_(int argc, unsigned char *argv[], struct option *opt,
                struct list_head *url_list)
 {
@@ -88,10 +88,15 @@ parse_options_(int argc, unsigned char *argv[], struct option *opt,
 			err = option_types[option->type].cmdline(option, &argv, &argc);
 
 			if (err) {
-				if (err[0])
+				if (err[0]) {
 					usrerror(gettext("Cannot parse option %s: %s"), argv[-1], err);
 
-				return 1;
+					return RET_ERROR;
+				}
+
+				/* XXX: Empty strings means all is well and have
+				 * a cup of shut the fsck up. */
+				return RET_COMMAND;
 
 			} else if (remote_url) {
 				if (url_list) add_to_string_list(url_list, remote_url, -1);
@@ -104,14 +109,14 @@ parse_options_(int argc, unsigned char *argv[], struct option *opt,
 		}
 	}
 
-	return 0;
+	return RET_OK;
 
 unknown_option:
 	usrerror(gettext("Unknown option %s"), argv[-1]);
-	return 1;
+	return RET_ERROR;
 }
 
-int
+enum retval
 parse_options(int argc, unsigned char *argv[], struct list_head *url_list)
 {
 	return parse_options_(argc, argv, cmdline_options, url_list);
@@ -274,6 +279,15 @@ remote_cmd(struct option *o, unsigned char ***argv, int *argc)
 		}
 
 		while (len > 0 && isspace(arg[len - 1])) len--;
+
+		if (len > 1) {
+			/* Skip possible string delimiters. Atleast urlview
+			 * seems to add them. */
+			if ((arg[0] == '\'' && arg[len - 1] == '\'')
+			    || (arg[0] == '"' && arg[len - 1] == '"'))
+				arg++, len -= 2;
+		}
+
 		if (len) remote_url = memacpy(arg, len);
 
 		break;
@@ -542,7 +556,7 @@ printhelp_cmd(struct option *option, unsigned char ***argv, int *argc)
 		print_full_help(config_options, "");
 	} else {
 		printf("%s\n\n%s:\n",
-		       gettext("Usage: elinks [OPTION]... [URL]"),
+		       gettext("Usage: elinks [OPTION]... [URL]..."),
 		       gettext("Options"));
 		if (!strcmp(option->name, "long-help")) {
 			print_full_help(cmdline_options, "-");
@@ -594,6 +608,24 @@ redir_cmd(struct option *option, unsigned char ***argv, int *argc)
 	return NULL;
 }
 
+static unsigned char *
+printconfigdump_cmd(struct option *option, unsigned char ***argv, int *argc)
+{
+	unsigned char *config_string;
+
+	/* Print all. */
+	get_opt_int("config.saving_style") = 2;
+
+	config_string = create_config_string("", "", config_options);
+	if (config_string) {
+		printf("%s", config_string);
+		mem_free(config_string);
+	}
+
+	fflush(stdout);
+	return "";
+}
+
 
 /**********************************************************************
  Options values
@@ -628,6 +660,11 @@ struct option_info cmdline_options_info[] = {
 		"If the path does not begin with a '/' it is assumed to be\n"
 		"relative to your HOME directory.")),
 
+	INIT_OPT_COMMAND("", N_("Print default configuration file to stdout"),
+		"config-dump", 0, printconfigdump_cmd,
+		N_("Print a configuration file with options set to the built-in\n"
+		"defaults to stdout.")),
+
 	INIT_OPT_COMMAND("", NULL, "conffile", OPT_HIDDEN, redir_cmd, NULL),
 
 	INIT_OPT_STRING("", N_("Name of configuration file"),
