@@ -1,5 +1,5 @@
 /* Config file manipulation */
-/* $Id: conf.c,v 1.152.2.1 2005/01/29 00:45:18 jonas Exp $ */
+/* $Id: conf.c,v 1.152.2.4 2005/09/14 13:02:18 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -100,7 +100,8 @@ parse_set(struct option *opt_tree, unsigned char **file, int *line,
 
 	/* Option name */
 	optname = *file;
-	while (isident(**file) || **file == '*' || **file == '.') (*file)++;
+	while (isident(**file) || **file == '*' || **file == '.' || **file == '+')
+		(*file)++;
 
 	bin = **file;
 	**file = '\0';
@@ -174,7 +175,8 @@ parse_unset(struct option *opt_tree, unsigned char **file, int *line,
 
 	/* Option name */
 	optname = *file;
-	while (isident(**file) || **file == '*' || **file == '.') (*file)++;
+	while (isident(**file) || **file == '*' || **file == '.' || **file == '+')
+		(*file)++;
 
 	bin = **file;
 	**file = '\0';
@@ -433,10 +435,22 @@ parse_config_file(struct option *options, unsigned char *name,
 		}
 	}
 
-	if (error_occured) {
-		fputc(7, stderr);
-		sleep(1);
-	}
+	if (!error_occured) return;
+
+	/* If an error occurred make sure that the user is notified and is able
+	 * to see it. First sound the bell. Then, if the text viewer is going to
+	 * be started, sleep for a while so the message will be visible before
+	 * ELinks starts drawing to on the screen and overwriting any error
+	 * messages. This should not be necessary for terminals supporting the
+	 * alternate screen mode but better to be safe. (debian bug 305017) */
+
+	fputc('\a', stderr);
+
+	if (get_cmd_opt_bool("dump")
+	    || get_cmd_opt_bool("source"))
+		return;
+
+	sleep(1);
 }
 
 
@@ -661,7 +675,7 @@ add_cfg_header_to_string(struct string *string, unsigned char *text)
 	add_to_string(string, "#\n\n");
 }
 
-static unsigned char *
+unsigned char *
 create_config_string(unsigned char *prefix, unsigned char *name,
 		     struct option *options)
 {
