@@ -1,5 +1,5 @@
 /* Sessions status managment */
-/* $Id: status.c,v 1.95.2.2 2005/04/06 08:26:55 jonas Exp $ */
+/* $Id: status.c,v 1.95.2.5 2005/09/14 13:15:39 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -212,11 +212,17 @@ get_current_link_info_and_title(struct session *ses,
 
 	link_title = get_current_link_title(doc_view);
 	if (link_title) {
-		if (*link_title) {
-			ret = straconcat(link_info, " - ", link_title, NULL);
-			mem_free(link_info);
-		}
+		unsigned char *src;
 
+		assert(*link_title);
+
+		/* Remove illicit chars. */
+		for (src = link_title; *src; src++)
+			if (!isprint(*src) || iscntrl(*src))
+				*src = '*';
+
+		ret = straconcat(link_info, " - ", link_title, NULL);
+		mem_free(link_info);
 		mem_free(link_title);
 	}
 
@@ -514,10 +520,8 @@ display_window_title(struct session *ses, struct terminal *term)
 	    && ses->doc_view->document->title[0])
 		doc_title = ses->doc_view->document->title;
 
-	title = straconcat("ELinks",
-			   doc_title ? " - " : NULL,
-			   doc_title,
-			   NULL);
+	title = doc_title ? straconcat(doc_title, " - ELinks", NULL)
+			  : stracpy("ELinks");
 	if (!title) return;
 
 	titlelen = strlen(title);
