@@ -1,5 +1,5 @@
 /* DOM document renderer */
-/* $Id: renderer.c,v 1.17.2.3 2005/04/06 10:52:31 jonas Exp $ */
+/* $Id: renderer.c,v 1.17.2.5 2005/09/14 13:30:26 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -365,6 +365,7 @@ add_dom_link(struct dom_renderer *renderer, unsigned char *string, int length)
 	link->where = where;
 	link->color.background = document->options.default_bg;
 	link->color.foreground = fgcolor;
+	link->number = document->nlinks;
 
 	init_template(&template, link->color.background, link->color.foreground);
 
@@ -623,20 +624,42 @@ render_dom_attribute_source(struct dom_navigator *navigator, struct dom_node *no
 
 		if (node->data.attribute.reference
 		    && valuelen - quoted * 2 > 0) {
-			/* Need to flush the first quoting delimiter so that
-			 * the renderers x position is at the start of the
-			 * value string. */
-			if (quoted) {
-				render_dom_text(renderer, template, value, 1);
-				value++;
-				valuelen--;
+			int skips;
+
+			/* Need to flush the first quoting delimiter and any
+			 * leading whitespace so that the renderers x position
+			 * is at the start of the value string. */
+			for (skips = 0; skips < valuelen; skips++) {
+				if ((quoted && skips == 0)
+				    || isspace(value[skips])
+				    || value[skips] < ' ')
+					continue;
+
+				break;
 			}
 
-			add_dom_link(renderer, value, valuelen - quoted);
+			if (skips > 0) {
+				render_dom_text(renderer, template, value, skips);
+				value    += skips;
+				valuelen -= skips;
+			}
 
-			if (quoted) {
-				value += valuelen - 1;
-				render_dom_text(renderer, template, value, 1);
+			/* Figure out what should be skipped after the actual
+			 * link text. */
+			for (skips = 0; skips < valuelen; skips++) {
+				if ((quoted && skips == 0)
+				    || isspace(value[valuelen - skips - 1])
+				    || value[valuelen - skips - 1] < ' ')
+					continue;
+
+				break;
+			}
+
+			add_dom_link(renderer, value, valuelen - skips);
+
+			if (skips > 0) {
+				value += valuelen - skips;
+				render_dom_text(renderer, template, value, skips);
 			}
 		} else {
 			render_dom_text(renderer, template, value, valuelen);
