@@ -1,5 +1,5 @@
 /* HTML parser */
-/* $Id: parser.c,v 1.513.2.8 2005/04/05 21:08:41 jonas Exp $ */
+/* $Id: parser.c,v 1.513.2.16 2005/09/14 14:57:01 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -29,6 +29,7 @@
 #include "document/renderer.h"
 #include "intl/charsets.h"
 #include "osdep/ascii.h"
+#include "protocol/date.h"
 #include "protocol/header.h"
 #include "protocol/uri.h"
 #include "sched/session.h"
@@ -137,7 +138,7 @@ get_target(unsigned char *a)
 	unsigned char *v = get_attr_val(a, "target");
 
 	if (v) {
-		if (!strcasecmp(v, "_self")) {
+		if (!*v || !strcasecmp(v, "_self")) {
 			mem_free(v);
 			v = stracpy(global_doc_opts->framename);
 		}
@@ -285,6 +286,11 @@ html_underline(unsigned char *a)
 	format.style.attr |= AT_UNDERLINE;
 }
 
+void
+html_tt(unsigned char *a)
+{
+}
+
 void
 html_fixed(unsigned char *a)
 {
@@ -324,8 +330,11 @@ html_focusable(unsigned char *a)
 
 	accesskey = get_attr_val(a, "accesskey");
 	if (accesskey) {
-		accesskey[0] = toupper(accesskey[0]);
-		format.accesskey = read_key(accesskey);
+		/* FIXME: support for entities and all Unicode characters.
+		 * For now, we only support simple printable character. */
+		if (accesskey[0] && !accesskey[1] && isprint(accesskey[0])) {
+			format.accesskey = accesskey[0];
+		}
 		mem_free(accesskey);
 	}
 
@@ -1164,6 +1173,60 @@ process_head(unsigned char *head)
 		}
 		mem_free(refresh);
 	}
+ 
+ 	if (!get_opt_bool("document.cache.ignore_cache_control")) {
+ 		unsigned char *d;
+ 		int no_cache = 0;
+ 		time_t expires = 0;
+ 
+ 		/* XXX: Code duplication with HTTP protocol backend. */
+ 		/* I am not entirely sure in what order we should process these
+ 		 * headers and if we should still process Cache-Control max-age
+ 		 * if we already set max age to date mentioned in Expires.
+ 		 * --jonas */
+ 		if ((d = parse_header(head, "Pragma", NULL))) {
+ 			if (strstr(d, "no-cache")) {
+ 				no_cache = 1;
+ 			}
+ 			mem_free(d);
+ 		}
+ 
+ 		if (!no_cache && (d = parse_header(head, "Cache-Control", NULL))) {
+ 			if (strstr(d, "no-cache") || strstr(d, "must-revalidate")) {
+ 				no_cache = 1;
+ 
+ 			} else  {
+ 				unsigned char *pos = strstr(d, "max-age=");
+ 
+ 				assert(!no_cache);
+ 
+ 				if (pos) {
+ 					/* Grab the number of seconds. */
+					expires = time(NULL) + atol(pos + 8);
+ 				}
+ 			}
+ 
+ 			mem_free(d);
+ 		}
+ 
+ 		if (!no_cache && (d = parse_header(head, "Expires", NULL))) {
+ 			/* Convert date to seconds. */
+ 			if (strstr(d, "now")) {
+ 				expires = time(NULL);
+ 			} else {
+ 				expires = parse_date(&d, NULL, 0, 1);
+ 			}
+ 
+ 			mem_free(d);
+ 		}
+ 
+ 
+ 		if (no_cache)
+ 			html_context.special_f(html_context.part, SP_CACHE_CONTROL);
+ 		else if (expires)
+ 			html_context.special_f(html_context.part,
+ 					       SP_CACHE_EXPIRES, expires);
+ 	}
 }
 
 
@@ -1262,7 +1325,8 @@ look_for_link(unsigned char **pos, unsigned char *eof, struct menu_item **menu,
 	      struct memory_list **ml, struct uri *href_base,
 	      unsigned char *target_base, struct conv_table *ct)
 {
-	unsigned char *attr, *label, *href, *name, *target;
+	unsigned char *attr, *href, *name, *target;
+	unsigned char *label = NULL;
 	struct link_def *ld;
 	struct menu_item *nm;
 	int nmenu;
