@@ -1,5 +1,5 @@
 /* HTML core parser routines */
-/* $Id: parse.c,v 1.102.2.7 2005/04/05 21:08:41 jonas Exp $ */
+/* $Id: parse.c,v 1.102.2.13 2005/09/14 15:08:36 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -420,6 +420,7 @@ void html_td(unsigned char *);
 void html_th(unsigned char *);
 void html_title(unsigned char *);
 void html_tr(unsigned char *);
+void html_tt(unsigned char *);
 void html_ul(unsigned char *);
 void html_underline(unsigned char *);
 void html_xmp(unsigned char *);
@@ -449,8 +450,6 @@ struct element_info {
 	int nopair;
 };
 
-#define NUMBER_OF_TAGS 65
-
 static struct element_info elements[] = {
 	{"A",		html_a,		0, 2},
 	{"ABBR",	html_italic,	0, 0},
@@ -518,12 +517,14 @@ static struct element_info elements[] = {
 	{"TH",		html_th,	0, 0},
 	{"TITLE",	html_title,	0, 0},
 	{"TR",		html_tr,	1, 0},
+	{"TT",          html_tt,	0, 2},
 	{"U",		html_underline,	0, 0},
 	{"UL",		html_ul,	2, 0},
 	{"XMP",		html_xmp,	2, 0},
 	{NULL,		NULL, 0, 0},
 };
 
+#define NUMBER_OF_TAGS ((sizeof(elements) / sizeof(struct element_info)) - 1)
 
 #ifndef USE_FASTFIND
 
@@ -691,9 +692,11 @@ next_break:
 				int length = html - base_pos;
 				int newlines = 0;
 
-				while (html + 5 < eof && !memcmp(html, "&#13;", 5)) {
+				while ((html + 5 < eof && html[0] == '&' && html[1] == '#') 
+				       && (!memcmp(html + 2, "13;", 3)
+					   || (html + 6 < eof && !strncasecmp(html + 2, "x0a;", 4)))) {
 					newlines++;
-					html += 5;
+					html += 5 + (html[4] != ';');
 				}
 
 				if (newlines) {
@@ -781,12 +784,6 @@ start_element(struct element_info *ei,
 	struct css_selector *selector = NULL;
 #endif
 
-	if (html_context.was_xmp) {
-		put_chrs("<", 1, html_context.put_chars_f, part);
-		html = prev_html + 1;
-		return html;
-	}
-
 	ln_break(ei->linebreak, html_context.line_break_f, part);
 
 	a = get_attr_val(attr, "id");
@@ -938,11 +935,7 @@ end_element(struct element_info *ei,
 	int lnb = 0;
 	int kill = 0;
 
-	if (html_context.was_xmp) {
-		if (ei->func != html_xmp)
-			return html;
-		html_context.was_xmp = 0;
-	}
+	if (ei->func == html_xmp) html_context.was_xmp = 0;
 
 	html_context.was_br = 0;
 	if (ei->nopair == 1 || ei->nopair == 3)
@@ -1008,6 +1001,13 @@ process_element(unsigned char *name, int namelen, int endingtag,
 #else
 	ei = (struct element_info *) fastfind_search(&ff_tags_index, name, namelen);
 #endif
+	if (html_context.was_xmp) {
+		if (!ei || ei->func != html_xmp || !endingtag) {
+			put_chrs("<", 1, html_context.put_chars_f, part);
+			return prev_html + 1;
+		}
+	}
+
 	if (!ei) return html;
 
 	if (!endingtag) {
