@@ -1,5 +1,5 @@
 /* HTML renderer */
-/* $Id: renderer.c,v 1.516.2.8 2005/04/05 21:08:41 jonas Exp $ */
+/* $Id: renderer.c,v 1.516.2.12 2005/05/01 22:50:38 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -114,6 +114,9 @@ struct renderer_context {
 
 	struct conv_table *convert_table;
 
+	/* Used for setting cache info from HTTP-EQUIV meta tags. */
+	struct cache_entry *cached;
+
 	int g_ctrl_num;
 	int empty_format;
 	int did_subscript;
@@ -1346,18 +1349,37 @@ html_special_form(struct part *part, struct form *form)
 			    || nform->form_end < form->form_num)
 				continue;
 
+			/* First check if the form has identical form numbers.
+			 * That should only be the case when the form being
+			 * added is in fact the same form in which case it
+			 * should be dropped. The fact that this can happen
+			 * suggests that the table renderering can be confused.
+			 * See bug 647 for a test case. */
+			if (nform->form_num == form->form_num
+			    && nform->form_end == form->form_end) {
+				done_form(form);
+				return;
+			}
+
 			/* The form start is inside an already added form, so
 			 * partition the space of the existing form and get
 			 * |old|new|. */
 			nform->form_end = form->form_num - 1;
 			assertm(nform->form_num <= nform->form_end,
-				"%d %d", nform->form_num, nform->form_end);
+				"[%d:%d] [%d:%d]", nform->form_num, nform->form_end,
+				form->form_num, form->form_end);
 			break;
 		}
 	} else {
 		/* If it is the first form make sure it eats the whole form
 		 * range. */
+#if 0
+		/* Disabled because in tables the parse order may lead to a
+		 * later form being parsed before a preceeding one causing the
+		 * wrong order if we set it to zero. Let's hope it doesn't break
+		 * anything else. */
 		form->form_num = 0;
+#endif
 	}
 
 	add_to_list(part->document->forms, form);
@@ -1515,6 +1537,28 @@ html_special(struct part *part, enum html_special_type c, ...)
 		case SP_USED:
 			va_end(l);
 			return (void *) (long) !!document;
+		case SP_CACHE_CONTROL:
+		{
+			struct cache_entry *cached = renderer_context.cached;
+
+			cached->cache_mode = CACHE_MODE_NEVER;
+			cached->expire = 0;
+			va_end(l);
+			break;
+		}
+		case SP_CACHE_EXPIRES:
+		{
+			time_t expires = va_arg(l, time_t);
+			struct cache_entry *cached = renderer_context.cached;
+
+			va_end(l);
+			if (!expires || cached->cache_mode == CACHE_MODE_NEVER)
+				break;
+
+			cached->max_age = expires;
+			cached->expire = 1;
+			break;
+		}
 		case SP_FRAMESET:
 		{
 			struct frameset_param *fsp = va_arg(l, struct frameset_param *);
@@ -1763,6 +1807,7 @@ render_html_document(struct cache_entry *cached, struct document *document,
 	if (!init_string(&head)) return;
 
 	renderer_context.g_ctrl_num = 0;
+	renderer_context.cached = cached;
 
 	start = buffer->source;
 	end = buffer->source + buffer->length;
@@ -1842,7 +1887,7 @@ render_html_document(struct cache_entry *cached, struct document *document,
 
 #if 0 /* debug purpose */
 	{
-		FILE *f = fopen("forms", "a");
+		FILE *f = fopen("forms", "ab");
 		struct form_control *form;
 		unsigned char *qq;
 		fprintf(f,"FORM:\n");
