@@ -1,5 +1,5 @@
 /* Plain text document renderer */
-/* $Id: renderer.c,v 1.171.2.3 2005/04/05 21:08:41 jonas Exp $ */
+/* $Id: renderer.c,v 1.171.2.4 2005/09/14 13:29:01 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -66,7 +66,7 @@ realloc_line(struct document *document, int x, int y)
 
 	if (!line) return NULL;
 
-	if (x > line->length) {
+	if (x != line->length) {
 		if (!ALIGN_LINE(&line->chars, line->length, x))
 			return NULL;
 
@@ -401,6 +401,8 @@ add_document_line(struct plain_renderer *renderer,
 
 	mem_free(line);
 
+	realloc_line(document, pos - startpos, lineno);
+
 	return width + expanded;
 }
 
