@@ -1,5 +1,5 @@
 /* Document (meta) refresh. */
-/* $Id: refresh.c,v 1.38.6.1 2005/04/05 21:08:40 jonas Exp $ */
+/* $Id: refresh.c,v 1.38.6.2 2005/05/01 22:18:20 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -41,6 +41,7 @@ init_document_refresh(unsigned char *url, unsigned long seconds)
 
 	refresh->seconds = seconds;
 	refresh->timer = -1;
+	refresh->restart = 1;
 
 	return refresh;
 }
@@ -86,6 +87,9 @@ do_document_refresh(void *data)
 	} else {
 		/* This makes sure that we send referer. */
 		goto_uri_frame(ses, refresh->uri, NULL, CACHE_MODE_NORMAL);
+		/* XXX: A possible very wrong work-around for refreshing used when
+		 * downloading files. */
+		refresh->restart = 0;
 	}
 }
 
@@ -101,7 +105,7 @@ start_document_refresh(struct document_refresh *refresh, struct session *ses)
 	 * to the session? The multiple refresh timers is triggered by
 	 * http://ttforums.owenrudge.net/login.php when pressing 'Log in' and
 	 * waiting for it to refresh. --jonas */
-	if (refresh->timer != -1)
+	if (!refresh->restart || refresh->timer != -1)
 		return;
 
 	/* Like bug 289 another sourceforge download thingy this time with
