@@ -1,5 +1,5 @@
 /* HTML renderer */
-/* $Id: renderer.c,v 1.140.2.3 2005/04/05 21:08:41 jonas Exp $ */
+/* $Id: renderer.c,v 1.140.2.4 2005/09/14 12:16:54 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -546,9 +546,17 @@ get_convert_table(unsigned char *head, int to_cp,
 
 	while (cp_index == -1) {
 		unsigned char *ct_charset;
+		unsigned char *meta;
 		unsigned char *a = parse_header(part, "Content-Type", &part);
 
 		if (!a) break;
+		/* Content type info from document meta header.
+		 * scan_http_equiv() appends the meta stuff to the protocol header before
+		 * this function is called. Last Content-Type header field is used. */
+
+		while ((meta = parse_header(part, "Content-Type", &part))) {
+			mem_free_set(&a, meta);
+		}
 
 		ct_charset = parse_header_param(a, "charset");
 		if (ct_charset) {
