@@ -1,5 +1,5 @@
 /* Charsets convertor */
-/* $Id: charsets.c,v 1.108.4.1 2005/04/05 21:08:41 jonas Exp $ */
+/* $Id: charsets.c,v 1.108.4.2 2005/09/14 12:07:14 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -522,7 +522,7 @@ get_entity_string(const unsigned char *str, const int strlen, int encoding)
 				else
 					goto end; /* Bad char. */
 				/* Limit to 0xFFFFFFFF. */
-				if (n == (unicode_val) 0xFFFFFFFF)
+				if (n == (unicode_val) 0xFFFFFFFFu)
 					goto end;
 			} while (--l);
 		}
