@@ -1,5 +1,5 @@
 /* Sockets-o-matic */
-/* $Id: connect.c,v 1.114.2.4 2005/04/05 21:08:41 jonas Exp $ */
+/* $Id: connect.c,v 1.114.2.6 2005/05/01 21:18:43 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -83,7 +83,7 @@ close_socket(struct connection *conn, struct connection_socket *socket)
 	if (conn && socket->ssl) ssl_close(conn, socket);
 #endif
 	close(socket->fd);
-	set_handlers(socket->fd, NULL, NULL, NULL, NULL);
+	clear_handlers(socket->fd);
 	socket->fd = -1;
 }
 
@@ -374,7 +374,7 @@ dns_found(void *data, int state)
 	/* Clear handlers, the connection to the previous RR really timed
 	 * out and doesn't interest us anymore. */
 	if (conn_info->socket && conn_info->socket->fd >= 0)
-		set_handlers(conn_info->socket->fd, NULL, NULL, NULL, conn);
+		clear_handlers(conn_info->socket->fd);
 
 	for (i = conn_info->triedno + 1; i < conn_info->addrno; i++) {
 #ifdef CONFIG_IPV6
@@ -491,6 +491,9 @@ dns_found(void *data, int state)
 		/* We set new state only if we already tried something new. */
 		if (trno != conn_info->triedno && !silent_fail)
 			set_connection_state(conn, -errno);
+		else if (trno == -1 && silent_fail)
+ 			/* All failed. */
+			set_connection_state(conn, S_NO_FORCED_DNS);
 
 		retry_connection(conn);
 		return;
@@ -607,7 +610,7 @@ write_select(struct connection *conn)
 		void (*f)(struct connection *) = wb->done;
 
 		conn->buffer = NULL;
-		set_handlers(wb->socket->fd, NULL, NULL, NULL, NULL);
+		clear_handlers(wb->socket->fd);
 		mem_free(wb);
 		f(conn);
 	}
@@ -658,7 +661,7 @@ read_select(struct connection *conn)
 	/* XXX: Should we set_connection_timeout() as we do in write_select()?
 	 * --pasky */
 
-	set_handlers(rb->socket->fd, NULL, NULL, NULL, NULL);
+	clear_handlers(rb->socket->fd);
 
 	if (!rb->freespace) {
 		int size = RD_SIZE(rb, rb->len);
