@@ -1,5 +1,5 @@
 /* Functionality for handling mime types */
-/* $Id: mime.c,v 1.70 2004/10/14 18:50:37 jonas Exp $ */
+/* $Id: mime.c,v 1.70.6.1 2005/09/14 13:23:26 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -65,6 +65,22 @@ get_content_filename(struct uri *uri, struct cache_entry *cached)
 	mem_free(pos);
 	if (!filename) return NULL;
 
+	/* Remove start and ending quotes. */
+	if (filename[0] == '"') {
+		int len = strlen(filename);
+
+		if (len > 1 && filename[len - 1] == '"') {
+			filename[len - 1] = 0;
+			memmove(filename, filename + 1, len);
+		}
+
+		/* It was an empty quotation: "" */
+		if (!filename[1]) {
+			mem_free(filename);
+			return NULL;
+		}
+	}
+
 	/* We don't want to add any directories from the path so make sure we
 	 * only add the filename. */
 	pos = get_filename_position(filename);
