@@ -1,9 +1,9 @@
-/* $Id: unix.h,v 1.5 2003/10/28 00:17:50 pasky Exp $ */
+/* $Id: unix.h,v 1.6 2004/08/14 23:23:47 jonas Exp $ */
 
 #ifndef EL__OSDEP_UNIX_UNIX_H
 #define EL__OSDEP_UNIX_UNIX_H
 
-#ifdef UNIX
+#ifdef CONFIG_UNIX
 
 /* TODO */
 
