@@ -1,5 +1,5 @@
 /* Internal "ftp" protocol implementation */
-/* $Id: ftp.c,v 1.182.2.5 2005/04/06 09:30:30 jonas Exp $ */
+/* $Id: ftp.c,v 1.182.2.8 2005/09/14 11:36:12 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -39,6 +39,7 @@
 #include "lowlevel/select.h"
 #include "modules/module.h"
 #include "osdep/osdep.h"
+#include "osdep/stat.h"
 #include "protocol/auth/auth.h"
 #include "protocol/ftp/ftp.h"
 #include "protocol/ftp/parse.h"
@@ -597,7 +598,7 @@ static struct ftp_connection_info *
 add_file_cmd_to_str(struct connection *conn)
 {
 #ifdef CONFIG_IPV6
-	struct sockaddr_in6 data_addr;
+	struct sockaddr_storage data_addr;
 #endif
 	struct ftp_connection_info *c_i;
 	struct string command;
@@ -631,8 +632,7 @@ add_file_cmd_to_str(struct connection *conn)
 		c_i->use_epsv = 1;
 
 	if (!c_i->use_epsv && conn->protocol_family == 1) {
-		data_sock = get_pasv6_socket(conn, conn->socket.fd,
-		 	    (struct sockaddr_storage *) &data_addr);
+		data_sock = get_pasv6_socket(conn, conn->socket.fd, &data_addr);
 		if (data_sock < 0)
 			return NULL;
 		conn->data_socket.fd = data_sock;
@@ -668,7 +668,8 @@ add_file_cmd_to_str(struct connection *conn)
 			if (c_i->use_epsv)
 				add_to_string(&command, "EPSV");
 			else
-				add_eprtcmd_to_string(&command, &data_addr);
+				add_eprtcmd_to_string(&command,
+					(struct sockaddr_in6 *) &data_addr);
 		else
 #endif
 			if (c_i->use_pasv)
@@ -702,7 +703,8 @@ add_file_cmd_to_str(struct connection *conn)
 			if (c_i->use_epsv)
 				add_to_string(&command, "EPSV");
 			else
-				add_eprtcmd_to_string(&command, &data_addr);
+				add_eprtcmd_to_string(&command,
+					(struct sockaddr_in6 *) &data_addr);
 		else
 #endif
 			if (c_i->use_pasv)
@@ -1217,7 +1219,7 @@ ftp_data_accept(struct connection *conn)
 
 	c_i->has_data = 1;
 
-	set_handlers(conn->data_socket.fd, NULL, NULL, NULL, NULL);
+	clear_handlers(conn->data_socket.fd);
 
 	if ((conn->protocol_family != 1 && c_i->use_pasv)
 #ifdef CONFIG_IPV6
@@ -1366,7 +1368,7 @@ out_of_mem:
 
 	if (c_i->dir) ADD_CONST("</pre>\n<hr>\n</body>\n</html>");
 
-	set_handlers(conn->data_socket.fd, NULL, NULL, NULL, NULL);
+	clear_handlers(conn->data_socket.fd);
 	close_socket(NULL, &conn->data_socket);
 
 	if (c_i->conn_state == 1) {
