@@ -1,5 +1,5 @@
 /* Parsing of FTP `ls' directory output. */
-/* $Id: parse.c,v 1.38.2.1 2005/04/06 09:30:31 jonas Exp $ */
+/* $Id: parse.c,v 1.38.2.8 2005/09/14 11:36:12 jonas Exp $ */
 
 /* Parts of this file was part of GNU Wget
  * Copyright (C) 1995, 1996, 1997, 2000, 2001 Free Software Foundation, Inc. */
@@ -25,6 +25,7 @@
 #include "elinks.h"
 
 #include "osdep/ascii.h"
+#include "osdep/stat.h"
 #include "protocol/date.h"
 #include "protocol/ftp/parse.h"
 #include "util/conv.h"
@@ -33,10 +34,10 @@
 
 
 #define skip_space_end(src, end) \
-	do { while ((src) < (end) && isspace(*(src))) (src)++; } while (0)
+	do { while ((src) < (end) && *(src) == ' ') (src)++; } while (0)
 
 #define skip_nonspace_end(src, end) \
-	do { while ((src) < (end) && !isspace(*(src))) (src)++; } while (0)
+	do { while ((src) < (end) && *(src) != ' ') (src)++; } while (0)
 
 static long
 parse_ftp_number(unsigned char **src, unsigned char *end, long from, long to)
@@ -133,7 +134,7 @@ static unsigned char ftp_unix_responses[] =
   /* UNIX-style listing, without inum and without blocks: */
  "-rw-r--r--   1 root     other        531 Jan 29 03:26 README\r\n"
  "dr-xr-xr-x   2 root     other        512 Apr  8  1994 etc\r\n"
- "dr-xr-xr-x   2 root     512 Apr  8  1994 et\r\nc"
+ "dr-xr-xr-x   2 root     512 Apr  8  1994 etc\r\n"
  "lrwxrwxrwx   1 root     other          7 Jan 25 00:17 bin -> usr/bin\r\n"
  /* Also produced by Microsoft's FTP servers for Windows: */
  "----------   1 owner    group         1803128 Jul 10 10:18 ls-lR.Z\r\n"
@@ -241,27 +242,33 @@ static struct ftp_file_info *
 parse_ftp_unix_response(struct ftp_file_info *info, unsigned char *src, int len)
 {
 	unsigned char *end = src + len;
-	enum ftp_file_type type = *src++;
-	unsigned char *pos = src;
+	unsigned char *pos;
 	struct tm mtime;
 	enum ftp_unix fact;
 
 	/* Decide the file type. */
-	switch (type) {
-	case FTP_FILE_PLAINFILE:
-	case FTP_FILE_DIRECTORY:
-	case FTP_FILE_SYMLINK:
-		info->type = type;
-		break;
+	{
+		enum ftp_file_type type = *src++;
+	
+		switch (type) {
+		case FTP_FILE_PLAINFILE:
+		case FTP_FILE_DIRECTORY:
+		case FTP_FILE_SYMLINK:
+			info->type = type;
+			break;
 
-	default:
-		info->type = FTP_FILE_UNKNOWN;
+		default:
+			info->type = FTP_FILE_UNKNOWN;
+		}
 	}
 
 	memset(&mtime, 0, sizeof(mtime));
 	mtime.tm_isdst = -1;
 
-	skip_space_end(src, end);
+	/* Following is only needed to handle NetWare listings which are not
+	 * (yet) handled. So disabled for now. --Zas */
+	/* skip_space_end(src, end); */
+	
 	fact = FTP_UNIX_PERMISSIONS;
 
 	for (pos = src; src < end; src = pos) {
