@@ -1,5 +1,5 @@
 /* URL parser and translator; implementation of RFC 2396. */
-/* $Id: uri.c,v 1.304.2.3 2005/04/05 21:08:42 jonas Exp $ */
+/* $Id: uri.c,v 1.304.2.4 2005/05/01 20:57:46 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -54,22 +54,6 @@ is_uri_dir_sep(struct uri *uri, unsigned char pos)
 }
 
 
-/* These are not available on some IRIX systems. Not that they are even
- * that important we should maybe just use MAX_STR_LEN. */
-/* FIXME: If we ever get a network/ directory or header file move it. */
-#ifndef INET_ADDRSTRLEN
-#define INET_ADDRSTRLEN 16
-#endif
-#ifndef INET6_ADDRSTRLEN
-#define INET6_ADDRSTRLEN 46
-#endif
-
-#ifdef CONFIG_IPV6
-#define IP_ADDRESS_BUFFER_SIZE INET6_ADDRSTRLEN
-#else
-#define IP_ADDRESS_BUFFER_SIZE INET_ADDRSTRLEN
-#endif
-
 int
 is_ip_address(unsigned char *address, int addresslen)
 {
