@@ -1,5 +1,5 @@
 /* Sessions managment - you'll find things here which you wouldn't expect */
-/* $Id: session.c,v 1.593.2.6 2005/04/06 09:11:19 jonas Exp $ */
+/* $Id: session.c,v 1.593.2.11 2005/09/14 13:19:09 jonas Exp $ */
 
 /* stpcpy */
 #ifndef _GNU_SOURCE
@@ -227,14 +227,32 @@ get_current_download(struct session *ses)
 
 void
 print_error_dialog(struct session *ses, enum connection_state state,
-		   enum connection_priority priority)
+		   struct uri *uri, enum connection_priority priority)
 {
-	/* Don't show error dialogs for missing CSS stylesheets */
-	if (priority == PRI_CSS) return;
+	struct string msg;
+	unsigned char *uristring;
 
-	info_box(ses->tab->term, MSGBOX_NO_TEXT_INTL,
+	/* Don't show error dialogs for missing CSS stylesheets */
+	if (priority == PRI_CSS
+	    || !init_string(&msg))
+		return;
+
+	uristring = uri ? get_uri_string(uri, URI_PUBLIC) : NULL;
+	if (uristring) {
+		decode_uri_for_display(uristring);
+		add_format_to_string(&msg,
+			_("Unable to retrieve %s", ses->tab->term),
+			uristring);
+		mem_free(uristring);
+		add_to_string(&msg, ":\n\n");
+	}
+
+	add_to_string(&msg, get_err_msg(state, ses->tab->term));
+
+	info_box(ses->tab->term, MSGBOX_FREE_TEXT,
 		 N_("Error"), ALIGN_CENTER,
-		 get_err_msg(state, ses->tab->term));
+		 msg.source);
+
 	/* TODO: retry */
 }
 
@@ -451,12 +469,15 @@ maybe_pre_format_html(struct cache_entry *cached, struct session *ses)
 	int len;
 	static int pre_format_html_event = EVENT_NONE;
 
-	if (!cached || cached->preformatted || list_empty(cached->frag))
+	if (!cached || cached->preformatted)
 		return;
 
 	fragment = get_cache_fragment(cached);
 	if (!fragment) return;
 
+	/* We cannot do anything if the data are fragmented. */
+	if (!list_is_singleton(cached->frag)) return;
+
 	src = fragment->data;
 	len = fragment->length;
 
@@ -538,14 +559,18 @@ doc_loading_callback(struct download *download, struct session *ses)
 		load_ecmascript_imports(ses, ses->doc_view);
 		process_file_requests(ses);
 
-		if (ses->doc_view->document->refresh
+		if (ses->doc_view
+		    && ses->doc_view->document
+		    && ses->doc_view->document->refresh
 		    && get_opt_bool("document.browse.refresh")) {
 			start_document_refresh(ses->doc_view->document->refresh,
 					       ses);
 		}
 
 		if (download->state != S_OK) {
-			print_error_dialog(ses, download->state, download->pri);
+			print_error_dialog(ses, download->state,
+					   ses->doc_view->document->uri,
+					   download->pri);
 		}
 
 	} else if (is_in_transfering_state(download->state)
@@ -728,7 +753,7 @@ setup_first_session(struct session *ses, struct uri *uri)
 	if (first_use) {
 		/* Only open the goto URL dialog if no URI was passed on the
 		 * command line. */
-		void *handler = uri ? dialog_goto_url_open : NULL;
+		void *handler = uri ? NULL : dialog_goto_url_open;
 
 		first_use = 0;
 
@@ -1022,7 +1047,7 @@ decode_session_info(struct terminal *term, struct terminal_info *info)
 				/* End loop if initialization fails */
 				len = 0;
 			} else if (bad_url) {
-				print_error_dialog(ses, S_BAD_URL, PRI_MAIN);
+				print_error_dialog(ses, S_BAD_URL, NULL, PRI_MAIN);
 			}
 
 		}
