@@ -1,5 +1,5 @@
 /* Sessions task management */
-/* $Id: task.c,v 1.146.2.6 2005/04/06 09:11:19 jonas Exp $ */
+/* $Id: task.c,v 1.146.2.8 2005/09/14 13:19:10 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -491,9 +491,10 @@ b:
 	}
 
 	if (is_in_progress_state((*download_p)->state)) {
-		*download_p = &cur_loc(ses)->download;
+		if (have_location(ses))
+			*download_p = &cur_loc(ses)->download;
 		change_connection(&ses->loading, *download_p, PRI_MAIN, 0);
-	} else {
+	} else if (have_location(ses)) {
 		cur_loc(ses)->download.state = ses->loading.state;
 	}
 
@@ -524,7 +525,8 @@ loading_callback(struct download *download, struct session *ses)
 	}
 
 	if (is_in_result_state(download->state) && download->state != S_OK) {
-		print_error_dialog(ses, download->state, download->pri);
+		struct uri *uri = download->conn ? download->conn->uri : NULL;
+		print_error_dialog(ses, download->state, uri, download->pri);
 		if (d == 0) reload(ses, CACHE_MODE_NORMAL);
 	}
 
@@ -542,7 +544,7 @@ do_follow_url(struct session *ses, struct uri *uri, unsigned char *target,
 	protocol_external_handler *external_handler;
 
 	if (!uri) {
-		print_error_dialog(ses, S_BAD_URL, PRI_CANCEL);
+		print_error_dialog(ses, S_BAD_URL, uri, PRI_CANCEL);
 		return;
 	}
 
