@@ -1,5 +1,5 @@
 /* Lua interface (scripting engine) */
-/* $Id: core.c,v 1.173.4.9 2005/04/06 11:12:56 jonas Exp $ */
+/* $Id: core.c,v 1.173.4.12 2005/05/06 23:40:46 miciah Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -569,8 +569,10 @@ l_get_option(LS)
 	/* Convert to an appropriate Lua type */
 	switch (opt->type) {
 	case OPT_BOOL:
+#ifdef HAVE_LUA5
 		lua_pushboolean(S, opt->value.number);
 		break;
+#endif
 	case OPT_INT:
 	case OPT_LONG:
 		lua_pushnumber(S, opt->value.number);
@@ -720,9 +722,9 @@ void
 alert_lua_error(unsigned char *msg)
 {
 	if (errterm) {
-		info_box(errterm, MSGBOX_NO_TEXT_INTL,
+		info_box(errterm, MSGBOX_NO_TEXT_INTL | MSGBOX_FREE_TEXT,
 			N_("Lua Error"), ALIGN_LEFT,
-			msg);
+			stracpy(msg));
 		return;
 	}
 
