@@ -1,5 +1,5 @@
 /* Lua scripting hooks */
-/* $Id: hooks.c,v 1.57.6.1 2005/01/29 01:02:32 jonas Exp $ */
+/* $Id: hooks.c,v 1.57.6.3 2005/09/13 15:41:24 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -55,8 +55,7 @@ script_hook_goto_url(va_list ap, void *data)
 
 		new_url = stracpy((unsigned char *) lua_tostring(L, -1));
 		if (new_url) {
-			mem_free(*url);
-			*url = new_url;
+			mem_free_set(url, new_url);
 		}
 	} else if (lua_isnil(L, -1)) {
 		(*url)[0] = 0;
@@ -99,8 +98,7 @@ script_hook_follow_url(va_list ap, void *data)
 
 		new_url = stracpy((unsigned char *) lua_tostring(L, -1));
 		if (new_url) {
-			mem_free(*url);
-			*url = new_url;
+			mem_free_set(url, new_url);
 		}
 	} else if (lua_isnil(L, -1)) {
 		(*url)[0] = 0;
@@ -183,9 +181,10 @@ script_hook_get_proxy(va_list ap, void *data)
 	if (err) return EVENT_HOOK_STATUS_NEXT;
 
 	if (lua_isstring(L, -1)) {
-		*new_proxy_url = stracpy((unsigned char *) lua_tostring(L, -1));
+		mem_free_set(new_proxy_url,
+		             stracpy((unsigned char *) lua_tostring(L, -1)));
 	} else if (lua_isnil(L, -1)) {
-		*new_proxy_url = NULL;
+		mem_free_set(new_proxy_url, NULL);
 	} else {
 		alert_lua_error("proxy_hook must return a string or nil");
 	}
