@@ -1,5 +1,5 @@
 /* Support for keyboard interface */
-/* $Id: kbd.c,v 1.112.6.5 2005/04/05 21:08:43 jonas Exp $ */
+/* $Id: kbd.c,v 1.112.6.8 2005/09/14 12:14:22 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -65,6 +65,7 @@ struct itrm {
 
 	unsigned int blocked:1;		/* Whether it was blocked */
 	unsigned int altscreen:1;	/* Whether to use alternate screen */
+	unsigned int touched_title:1;	/* Whether the term title was changed */
 };
 
 static struct itrm *ditrm = NULL;
@@ -230,6 +231,20 @@ resize_terminal(void)
 	queue_event(ditrm, (char *) &ev, sizeof(ev));
 }
 
+static void
+set_terminal_name(unsigned char name[MAX_TERM_LEN])
+{
+	unsigned char *term = getenv("TERM");
+	int i;
+
+	memset(name, 0, MAX_TERM_LEN);
+
+	if (!term) return;
+
+	for (i = 0; term[i] != 0 && i < MAX_TERM_LEN - 1; i++)
+		name[i] = isident(term[i]) ? term[i] : '-';
+}
+
 
 static int
 setraw(int fd, struct termios *p)
@@ -302,13 +317,7 @@ handle_trm(int std_in, int std_out, int sock_in, int sock_out, int ctl_in,
 
 	handle_terminal_resize(ctl_in, resize_terminal);
 
-	ts = getenv("TERM");
-	if (ts) {
-		int i;
-
-		for (i = 0; ts[i] != 0 && i < MAX_TERM_LEN; i++)
-			info.name[i] = isident(ts[i]) ? ts[i] : '-';
-	}
+	set_terminal_name(info.name);
 
 	ts = get_cwd();
 	if (ts) {
@@ -380,21 +389,31 @@ free_trm(struct itrm *itrm)
 {
 	if (!itrm) return;
 
-	if (itrm->orig_title) {
+	if (itrm->orig_title && *itrm->orig_title) {
 		set_window_title(itrm->orig_title);
-		mem_free(itrm->orig_title);
-		itrm->orig_title = NULL;
+
+	} else if (itrm->touched_title) {
+		/* Set the window title to the value of $TERM if X11 wasn't
+		 * compiled in. Should hopefully make at least half the users
+		 * happy. (debian bug #312955) */
+		unsigned char title[MAX_TERM_LEN];
+
+		set_terminal_name(title);
+		if (*title)
+			set_window_title(title);
 	}
 
+	mem_free_set(&itrm->orig_title, NULL);
+
 	unhandle_terminal_resize(itrm->ctl_in);
 	unhandle_mouse(itrm->mouse_h);
 	send_done_sequence(itrm->std_out,itrm->altscreen);
 	tcsetattr(itrm->ctl_in, TCSANOW, &itrm->t);
 
-	set_handlers(itrm->std_in, NULL, NULL, NULL, NULL);
-	set_handlers(itrm->sock_in, NULL, NULL, NULL, NULL);
-	set_handlers(itrm->std_out, NULL, NULL, NULL, NULL);
-	set_handlers(itrm->sock_out, NULL, NULL, NULL, NULL);
+	clear_handlers(itrm->std_in);
+	clear_handlers(itrm->sock_in);
+	clear_handlers(itrm->std_out);
+	clear_handlers(itrm->sock_out);
 
 	if (itrm->timer != -1)
 		kill_timer(itrm->timer);
@@ -441,8 +460,11 @@ dispatch_special(unsigned char *text)
 {
 	switch (text[0]) {
 		case TERM_FN_TITLE:
-			if (ditrm && !ditrm->orig_title)
-				ditrm->orig_title = get_window_title();
+			if (ditrm) {
+				if (!ditrm->orig_title)
+					ditrm->orig_title = get_window_title();
+				ditrm->touched_title = 1;
+			}
 			set_window_title(text + 1);
 			break;
 		case TERM_FN_RESIZE:
@@ -679,8 +701,8 @@ decode_terminal_mouse_escape_sequence(struct itrm *itrm, struct term_event *ev,
 		    case TW_BUTT_LEFT:   mouse->button = B_LEFT | ( (xterm_button & TW_BUTT_LEFT) ? B_UP : B_DOWN ); break;
 		    case TW_BUTT_MIDDLE: mouse->button = B_MIDDLE | ( (xterm_button & TW_BUTT_MIDDLE) ? B_UP : B_DOWN ); break;
 		    case TW_BUTT_RIGHT:  mouse->button = B_RIGHT | ( (xterm_button & TW_BUTT_RIGHT) ? B_UP : B_DOWN ); break;
-		    case 0: mouse->button = B_DRAG;
-		    /* default : Twin protocol error */
+		    case 0: mouse->button = B_DRAG; break;
+		    default: mouse->button = 0; /* Twin protocol error */
 		}
 		xterm_button = itrm->kqueue[el] - ' ';
 		el += 5;
