@@ -1,5 +1,5 @@
 /* File utilities */
-/* $Id: file.c,v 1.42.4.1 2005/04/05 21:08:43 jonas Exp $ */
+/* $Id: file.c,v 1.42.4.2 2005/05/01 22:03:23 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -70,7 +70,7 @@ file_can_read(const unsigned char *filename)
 #ifdef HAVE_ACCESS
 	return access(filename, R_OK) >= 0;
 #else
-	FILE *f = fopen(filename, "r");
+	FILE *f = fopen(filename, "rb");
 	int ok = !!f;
 
 	if (f) fclose(f);
