@@ -1,5 +1,5 @@
 /* Textarea form item handlers */
-/* $Id: textarea.c,v 1.143.2.1 2005/04/06 08:59:39 jonas Exp $ */
+/* $Id: textarea.c,v 1.143.2.3 2005/09/14 13:14:52 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -315,7 +315,7 @@ static unsigned char *
 load_textarea_file(unsigned char *filename, int maxlength)
 {
 	unsigned char *value = NULL;
-	FILE *file = fopen(filename, "r+");
+	FILE *file = fopen(filename, "rb+");
 	int filelen = -1;
 
 	if (!file) return NULL;
@@ -372,13 +372,16 @@ textarea_edit(int op, struct terminal *term_, struct form_state *fs_,
 	}
 
 	if (op == 0 && !textarea_editor) {
-		unsigned char *ed = getenv("EDITOR");
+		unsigned char *ed = get_opt_str("document.browse.forms.editor");
 		unsigned char *ex;
 
 		fn = save_textarea_file(fs_->value);
 		if (!fn) return;
 
-		if (!ed || !*ed) ed = "vi";
+		if (!ed || !*ed) {
+			ed = getenv("EDITOR");
+			if (!ed || !*ed) ed = "vi";
+		}
 
 		ex = straconcat(ed, " ", fn, NULL);
 		if (!ex) {
