@@ -1,5 +1,5 @@
 /* HTML viewer (and much more) */
-/* $Id: view.c,v 1.665.2.7 2005/04/06 09:02:09 jonas Exp $ */
+/* $Id: view.c,v 1.665.2.11 2005/09/14 15:16:25 jonas Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -90,7 +90,7 @@ move_down(struct session *ses, struct document_view *doc_view, int type)
 	assert(ses && doc_view && doc_view->vs);
 	if_assert_failed return FRAME_EVENT_OK;
 
-	ses->navigate_mode = NAVIGATE_LINKWISE;	/* XXX: why here and not in move_up() ??? */
+	assert(ses->navigate_mode == NAVIGATE_LINKWISE);	/* XXX: drop it at some time. --Zas */
 
 	newpos = doc_view->vs->y + doc_view->box.height;
 	if (newpos < doc_view->document->height)
@@ -115,6 +115,7 @@ move_page_down(struct session *ses, struct document_view *doc_view)
 
 	count = ses->kbdprefix.repeat_count;
 	ses->kbdprefix.repeat_count = 0;
+	ses->navigate_mode = NAVIGATE_LINKWISE;
 
 	do {
 		status = move_down(ses, doc_view, 0);
@@ -132,6 +133,8 @@ move_up(struct session *ses, struct document_view *doc_view, int type)
 	assert(ses && doc_view && doc_view->vs);
 	if_assert_failed return FRAME_EVENT_OK;
 
+	assert(ses->navigate_mode == NAVIGATE_LINKWISE);	/* XXX: drop it at some time. --Zas */
+
 	if (doc_view->vs->y == 0) return FRAME_EVENT_OK;
 
 	doc_view->vs->y -= doc_view->box.height;
@@ -156,6 +159,7 @@ move_page_up(struct session *ses, struct document_view *doc_view)
 
 	count = ses->kbdprefix.repeat_count;
 	ses->kbdprefix.repeat_count = 0;
+	ses->navigate_mode = NAVIGATE_LINKWISE;
 
 	do {
 		status = move_up(ses, doc_view, 0);
@@ -177,12 +181,11 @@ move_link(struct session *ses, struct document_view *doc_view, int direction,
 
 	ses->navigate_mode = NAVIGATE_LINKWISE;
 
-	if (doc_view->document->nlinks == 0) {
-		/* There are no links, therefore the only sensible value for
-		 * wraparound_bound is -1 (no link selected). */
+	if (doc_view->document->nlinks < 2) {
+		/* Wraparound only makes sense with more than one link. */
 		wraparound_bound = -1;
 	} else {
-		/* We only bother this option is there's some links
+		/* We only bother this option if there's some links
 		 * in document. */
 		wraparound = get_opt_bool("document.browse.links.wraparound");
 	}
@@ -692,10 +695,12 @@ try_prefix_key(struct session *ses, struct document_view *doc_view,
 	struct document_options *doc_opts = &document->options;
 	int digit = get_kbd_key(ev) - '0';
 
-	if (!isdigit(get_kbd_key(ev)))
+	if (digit < 0 || digit > 9)
 		return FRAME_EVENT_IGNORED;
 
 	if (get_kbd_modifier(ev)
+	    || ses->kbdprefix.repeat_count /* The user has already begun
+	                                    * entering a prefix. */
 	    || !doc_opts->num_links_key
 	    || (doc_opts->num_links_key == 1 && !doc_opts->num_links_display)) {
 		/* Repeat count.
